@@ -1,19 +1,20 @@
 CLI_CONFIG = {
+    "config": {"options": ["-c"], "help": "The path to a .yaml config file"},
     # Describe Options
     "desc_glob": {
         "display_priority": 0,
         "positional": True,
-        "subcommands": ["describe"],
+        "subcommands": ["describe", "refresh"],
         "help": "A glob to match the refs that should be ran",
     },
     "progress": {
         "action": "store_true",
-        "subcommands": ["describe"],
+        "subcommands": ["describe", "refresh"],
         "help": "Show a progress bar",
     },
     "hard_fail": {
         "action": "store_true",
-        "subcommands": ["describe"],
+        "subcommands": ["describe", "refresh"],
         "help": "Hard stop the first time an error is raised",
     },
     "filter": {
@@ -37,16 +38,18 @@ CLI_CONFIG = {
     },
     # State and validate options
     "run_name": {
-        "subcommands": ["state", "exec", "describe", "validate"],
+        "subcommands": ["state", "exec", "describe", "validate", "refresh", "restore"],
     },
-    "sls_sources": {"nargs": "*", "subcommands": ["state"]},
+    "sls_sources": {"nargs": "*", "subcommands": ["state", "validate"]},
+    "param_sources": {"nargs": "*", "subcommands": ["state", "describe"]},
     "test": {"options": ["-t"], "action": "store_true", "subcommands": ["state"]},
     "tree": {
         "options": ["-T"],
         "subcommands": ["state", "validate"],
     },
-    "cache_dir": {"subcommands": ["state", "validate"]},
+    "cache_dir": {"subcommands": ["state", "validate", "refresh", "restore"]},
     "root_dir": {"subcommands": ["state", "validate"]},
+    "params": {"subcommands": ["state", "describe"]},
     "render": {
         "subcommands": ["state", "validate"],
     },
@@ -63,9 +66,11 @@ CLI_CONFIG = {
     },
     "output": {
         "source": "rend",
-        "subcommands": ["exec", "state", "describe", "decrypt", "validate"],
+        "subcommands": ["exec", "state", "describe", "decrypt", "validate", "refresh"],
     },
     "sls": {"positional": True, "nargs": "*", "subcommands": ["state", "validate"]},
+    "esm_plugin": {"subcommands": ["state", "validate", "refresh", "restore"]},
+    "esm_profile": {"subcommands": ["state", "validate", "refresh", "restore"]},
     # ACCT options
     "input_file": {
         "source": "acct",
@@ -79,16 +84,25 @@ CLI_CONFIG = {
     "acct_file": {
         "source": "acct",
         "os": "ACCT_FILE",
-        "subcommands": ["state", "exec", "describe", "validate"],
+        "subcommands": ["state", "exec", "describe", "validate", "refresh", "restore"],
     },
     "acct_key": {
         "source": "acct",
         "os": "ACCT_KEY",
-        "subcommands": ["state", "exec", "describe", "encrypt", "decrypt", "validate"],
+        "subcommands": [
+            "state",
+            "exec",
+            "describe",
+            "encrypt",
+            "decrypt",
+            "validate",
+            "refresh",
+            "restore",
+        ],
     },
     "acct_profile": {
         "os": "ACCT_PROFILE",
-        "subcommands": ["state", "exec", "describe", "validate"],
+        "subcommands": ["state", "exec", "describe", "validate", "refresh"],
     },
     "crypto_plugin": {
         "source": "acct",
@@ -99,17 +113,39 @@ CLI_CONFIG = {
         "source": "evbus",
         "subcommands": ["exec", "describe", "state", "validate"],
     },
+    # RESTORE options
+    "esm_cache_file": {"positional": True, "subcommands": ["restore"]},
 }
 
 CONFIG = {
+    "config": {
+        "default": None,
+        "help": "Load extra options from a configuration file onto hub.OPT.idem",
+    },
+    "esm_plugin": {
+        "default": "local",
+        "help": "The esm (enforced state manager) plugin to use with a state run",
+    },
+    "esm_serial_plugin": {
+        "default": "msgpack",
+        "help": "The serial plugin used to store ESM data",
+    },
+    "esm_profile": {
+        "default": "default",
+        "help": "The acct profile to use with the enforced state manager",
+    },
     "run_name": {
         "default": "cli",
-        "help": "A unique ID to assign to this run",
+        "help": "A name for this run, this is used in internal tracking and to organize events",
     },
     "sls_sources": {
         "default": [],
         "help": "list off the sources that should be used for gathering sls files and data",
     },
+    "param_sources": {
+        "default": [],
+        "help": "list off the sources that should be used for gathering parameter sls files",
+    },
     "test": {
         "default": False,
         "help": "Set the idem run to execute in test mode. No changes will be made, idem will only detect if changes will be made in a real run.",
@@ -118,9 +154,13 @@ CONFIG = {
         "default": "",
         "help": "The directory containing sls files",
     },
+    "params": {
+        "default": "",
+        "help": "The location of param.sls file containing parameter definitions",
+    },
     "cache_dir": {
         "default": "/var/cache/idem",
-        "help": "The location to use for the cache directory",
+        "help": "The location to use for the cache directory relative to the root_dir",
     },
     "root_dir": {
         "default": "/",
@@ -185,14 +225,25 @@ SUBCOMMANDS = {
     },
     "validate": {
         "desc": "Validate the given SLS tree and return the internal working data for the tree",
-        "help": "COmmands to validate SLS files",
+        "help": "Commands to validate SLS files",
+    },
+    "refresh": {
+        "desc": "Update enforced state management with described resources",
+        "help": "Update enforced state management with described resources",
+    },
+    "restore": {
+        "desc": "Restore the enforced managed state from a cache file",
+        "help": "Restore the enforced managed state from a cache file",
     },
 }
 DYNE = {
+    "esm": ["esm"],
     "idem": ["idem"],
     "exec": ["exec"],
+    "log": ["log"],
     "states": ["states"],
     "tool": ["tool"],
     "output": ["output"],
     "reconcile": ["reconcile"],
+    "acct": ["acct"],
 }
