@@ -46,23 +46,19 @@ async def aecho(hub, value):
 
 async def event(
     hub,
-    routing_key: str,
     body: str,
     ingress_profile: str = "default",
     tags: Dict[str, Any] = None,
 ):
     """
-    :param routing_key: The ingress channel to publish to
     :param body: The event body
     :param ingress_profile: The ingress profile to allowlist for this event
 
     .. code-block:: bash
 
-        $ idem exec test.event routing_key body ingress_profile="default" --serialize-plugin="json"
-        $ idem exec test.event routing_key="key" body="my_event" ingress_profile="default" --serialize-plugin="json"
+        $ idem exec test.event body ingress_profile="default" --serialize-plugin="json"
+        $ idem exec test.event body="my_event" ingress_profile="default" --serialize-plugin="json"
     """
-    event_kwargs = dict(
-        routing_key=routing_key, body=body, profile=ingress_profile, tags=tags
-    )
+    event_kwargs = dict(body=body, profile=ingress_profile, tags=tags)
     await hub.idem.event.put(**event_kwargs)
     return {"result": True, "ret": event_kwargs}
