@@ -1,4 +1,4 @@
-def stage(hub, name):
+def stage(hub, name: str):
     """
     Apply the exclude value
     """
