@@ -1,4 +1,8 @@
-async def modify(hub, name, chunk):
+from typing import Any
+from typing import Dict
+
+
+async def modify(hub, name: str, chunk: Dict[str, Any]) -> Dict[str, Any]:
     """
     Check the state containing the target func and call the mod_creds
     function if present. Therefore gathering the list of creds systems
