@@ -1,4 +1,8 @@
-def define(hub):
+from typing import Any
+from typing import Dict
+
+
+def define(hub) -> Dict[str, Any]:
     """
     Define how the watch requisite should behave
     """
