@@ -23,9 +23,13 @@ async def gather(hub, name, *sls):
 async def get_blocks(hub, name, sls):
     # Returns 'False' if the SLS file cannot be found
     for sls_ref in sls:
-        cfn = await hub.idem.get.ref(name, sls_ref)
+        blocks = None
+        try:
+            cfn = await hub.idem.get.ref(name, sls_ref)
+        except:
+            ...
         if not cfn:
-            msg = f"SLS ref {sls_ref} did not resolve to a file"
+            msg = f"SLS ref '{sls_ref}' did not resolve to a file"
             hub.log.debug(msg)
             hub.idem.RUNS[name]["errors"].append(msg)
             return False
@@ -61,7 +65,9 @@ async def render(hub, name):
                     continue
             if clear:
                 state = await hub.rend.init.parse_bytes(
-                    block, hub.idem.RUNS[name]["render"]
+                    block,
+                    hub.idem.RUNS[name]["render"],
+                    hub.idem.RUNS[name]["params"],  # params
                 )
                 await hub.idem.resolve.introduce(name, state, sls_ref, cfn)
                 rendered[sls_ref] = bname
@@ -92,13 +98,16 @@ async def introduce(hub, name, state, sls_ref, cfn):
     hub.idem.resolve.decls(name, state, sls_ref)
     hub.idem.resolve.iorder(name, state)
     await hub.idem.resolve.includes(name, include, sls_ref, cfn)
-    await hub.idem.event.put(
-        routing_key=name,
-        profile="idem-high",
-        body=state,
-        tags={"type": "state-high-data", "ref": "idem.resolve.introduce"},
-    )
-    hub.idem.RUNS[name]["high"].update(state)
+
+    # If we are just doing parameter parsing and not doing state execution,
+    # skip the next steps.
+    if not hub.idem.RUNS[name]["params_processing"]:
+        await hub.idem.event.put(
+            profile="idem-high",
+            body=state,
+            tags={"type": "state-high-data", "ref": "idem.resolve.introduce"},
+        )
+        hub.idem.RUNS[name]["high"].update(state)
 
 
 def iorder(hub, name, state):
@@ -204,6 +213,14 @@ def decls(hub, name, state, sls_ref):
             if id_ == "__exclude__":
                 continue
 
+            # In case of params_processing being true, or in other words, when we are doing
+            # parameter processing only: we will just read the key and value pairs and add
+            # to hub.idem.RUNS[name]["params"] dict. Then we can access the parameter value
+            # as {{ params.get('foo') }}
+            if hub.idem.RUNS[name]["params_processing"] and state[id_] is not None:
+                hub.idem.RUNS[name]["params"][id_] = state[id_]
+                continue
+
             if isinstance(state[id_], str):
                 # Is this is a short state, it needs to be padded
                 if "." in state[id_]:
@@ -211,10 +228,23 @@ def decls(hub, name, state, sls_ref):
                     state_ref = ".".join(comps[:-1])
                     state[id_] = {"__sls__": sls_ref, state_ref: [comps[-1]]}
                     continue
+
             hub.idem.RUNS[name]["errors"].append(
                 f"ID {id_} in SLS {sls_ref} is not a dictionary"
             )
             continue
+
+        # This handles the parameter parsing when value is of type dict.
+        # Similar to the case above where we handled non dict value types: here
+        # we will just read the key and value pairs and add to
+        # hub.idem.RUNS[name]["params"] dict. This will ensure we will be able to
+        # access these objects like: {{ params.get('foo').get('bar') }}
+        # In similar manner array elements can be accessed like:
+        # {{ params['foo_array'][0] }}
+        if hub.idem.RUNS[name]["params_processing"]:
+            hub.idem.RUNS[name]["params"][id_] = state[id_]
+            continue
+
         skeys = set()
         for key in list(state[id_]):
             if key.startswith("_"):
