@@ -1,4 +1,9 @@
-def check(hub, rlist):
+from typing import Any
+from typing import Dict
+from typing import List
+
+
+def check(hub, rlist: List[Dict[str, Any]]) -> List[str]:
     """
     Chek the resolve list from the requisite systems and return errors from all
     errored requisites
