@@ -1,4 +1,9 @@
-def check(hub, rlist):
+from typing import Any
+from typing import Dict
+from typing import List
+
+
+def check(hub, rlist: List[Dict[str, Any]]) -> List[str]:
     """
     Check if any of the required list passes. If a single check passes then
     all is well, only return the errors is ALL FAIL
