@@ -1,4 +1,15 @@
-def check(hub, name, ctx, condition, reqret, chunk):
+from typing import Any
+from typing import Dict
+
+
+def check(
+    hub,
+    name: str,
+    ctx: Dict[str, Any],
+    condition: Any,
+    reqret: Dict[str, Any],
+    chunk: Dict[str, Any],
+) -> Dict[str, Any]:
     """
     Check to see if the result is True
     """
