@@ -1,7 +1,16 @@
 import copy
+from typing import Any
+from typing import Dict
 
 
-def check(hub, name, ctx, condition, reqret, chunk):
+def check(
+    hub,
+    name: str,
+    ctx: Dict[str, Any],
+    condition: Any,
+    reqret: Dict[str, Any],
+    chunk: Dict[str, Any],
+) -> Dict[str, Any]:
     """
     Check to see if the reqret state will make changes in the future
     """
