@@ -1,7 +1,10 @@
 import asyncio
+from typing import Dict
 
 
-async def runtime(hub, name, ctx, seq, low, running):
+async def runtime(
+    hub, name: str, ctx: Dict, seq: Dict, low: Dict, running: Dict, managed_state: Dict
+):
     """
     Execute the runtime in parallel mode
     """
@@ -25,6 +28,7 @@ async def runtime(hub, name, ctx, seq, low, running):
                 seq[ind],
                 running,
                 hub.idem.RUNS[name]["run_num"],
+                managed_state,
             )
         )
         hub.idem.RUNS[name]["run_num"] += 1
