@@ -1,4 +1,9 @@
-async def runtime(hub, name, ctx, seq, low, running):
+from typing import Dict
+
+
+async def runtime(
+    hub, name: str, ctx: Dict, seq: Dict, low: Dict, running: Dict, managed_state: Dict
+):
     """
     Execute the runtime in parallel mode
     """
@@ -14,7 +19,13 @@ async def runtime(hub, name, ctx, seq, low, running):
         pass
     for ind in inds:
         await hub.idem.rules.init.run(
-            name, ctx, low, seq[ind], running, hub.idem.RUNS[name]["run_num"]
+            name,
+            ctx,
+            low,
+            seq[ind],
+            running,
+            hub.idem.RUNS[name]["run_num"],
+            managed_state,
         )
         hub.idem.RUNS[name]["run_num"] += 1
     if len(low) <= len(running):
