@@ -8,7 +8,7 @@ import shutil
 __virtualname__ = "file"
 
 
-async def cache(hub, cache_dir, source, loc):
+async def cache(hub, cache_dir: str, source: str, loc: str) -> str:
     """
     Take a file from a location definition and cache it in the target location
     """
