@@ -7,7 +7,7 @@ import os
 __virtualname__ = "json"
 
 
-async def cache(hub, cache_dir, source, loc):
+async def cache(hub, cache_dir: str, source: str, loc: str) -> str:
     """
     Take a file from a location definition and cache it in the target location
     """
