@@ -5,7 +5,6 @@ from typing import Any
 from typing import Dict
 from typing import List
 
-import aiofiles
 import dict_tools.update
 
 __func_alias__ = {"compile_": "compile"}
@@ -30,17 +29,12 @@ def update_status(hub, name: str, status_: Status):
     if name in hub.idem.RUNS:
         hub.idem.RUNS[name]["status"] = status_
     hub.idem.event.put_nowait(
-        routing_key=name,
         profile="idem-status",
         body=status_.name,
         tags={"ref": "idem.state.update_status", "type": "state-status"},
     )
 
 
-def sanitized_run_data(hub, name):
-    return {k: v for k, v in hub.idem.RUNS[name].items() if k != "acct_data"}
-
-
 async def create(
     hub,
     name: str,
@@ -53,21 +47,20 @@ async def create(
     acct_file: str,
     acct_key: str,
     acct_profile: str,
-    acct_blob: bytes = None,
+    acct_blob: bytes,
+    managed_state: Dict[str, Any],
+    param_sources: List[str],
 ):
     """
     Create a new instance to execute against
     """
-    acct_data = {}
-    if acct_key:
-        if acct_file:
-            async with aiofiles.open(acct_file, "rb") as fh:
-                acct_blob = await fh.read()
-        if acct_blob:
-            acct_data = await hub.acct.init.unlock_blob(acct_blob, acct_key=acct_key)
+    acct_data = await hub.idem.acct.data(
+        acct_key=acct_key, acct_file=acct_file, acct_blob=acct_blob
+    )
 
     hub.idem.RUNS[name] = {
         "sls_sources": sls_sources,
+        "param_sources": param_sources,
         "render": render,
         "runtime": runtime,
         "subs": subs,
@@ -77,6 +70,10 @@ async def create(
         "resolved": set(),
         "files": set(),
         "high": {},
+        # params_processing flag is used to indicate to resolve.py
+        # code that we only intend to parameter parsing
+        "params_processing": False,
+        "params": {},
         "post_low": [],
         "errors": [],
         "iorder": 100000,
@@ -89,14 +86,9 @@ async def create(
         "acct_profile": acct_profile,
         "acct_data": acct_data,
         "status": Status.CREATED,
+        "managed_state": managed_state,
+        "processed_sls_sources": {},
     }
-    # Fire an event with the run data for all states
-    await hub.idem.event.put(
-        routing_key=name,
-        profile="idem-run",
-        body=hub.idem.state.sanitized_run_data(name),
-        tags={"ref": "idem.state.create", "type": "state-run"},
-    )
 
 
 async def validate(
@@ -129,11 +121,16 @@ async def validate(
         acct_key=acct_key,
         acct_profile=acct_profile,
         acct_blob=acct_blob,
+        managed_state=None,
+        param_sources=None,
     )
     # Get the sls file
     # render it
     # compile high data to "new" low data (bypass keyword issues)
     # Run the low data using act/idem
+    hub.idem.RUNS[name]["params"] = hub.tool.parameter.get_validate_params()
+    # process sls-sources
+    hub.idem.sls.source.init.process(name)
     hub.idem.RUNS[name]["status"] = Status.GATHERING
     await hub.idem.resolve.gather(name, *sls)
     if hub.idem.RUNS[name]["errors"]:
@@ -144,6 +141,7 @@ async def validate(
     if hub.idem.RUNS[name]["errors"]:
         hub.idem.RUNS[name]["status"] = Status.COMPILATION_ERROR
         return
+    await hub.idem.state.validate_(name)
 
 
 async def apply(
@@ -160,6 +158,9 @@ async def apply(
     acct_key: str = None,
     acct_profile: str = "default",
     acct_blob: bytes = None,
+    managed_state: Dict[str, Any] = None,
+    param_sources: List[str] = [],
+    params_file: str = None,
 ):
     """
     Run idem!
@@ -176,7 +177,20 @@ async def apply(
         acct_key=acct_key,
         acct_profile=acct_profile,
         acct_blob=acct_blob,
+        managed_state=managed_state,
+        param_sources=param_sources,
     )
+
+    if params_file is not None and len(params_file) > 0:
+        # Ensuring that only parameters are getting parsed.
+        hub.idem.RUNS[name]["params_processing"] = True
+        await hub.idem.resolve.gather(name, params_file)
+        # Restore the value to False so that for rest of the SLS are handled in normal manner.
+        hub.idem.RUNS[name]["params_processing"] = False
+        if hub.idem.RUNS[name]["errors"]:
+            return
+    # process sls-sources
+    hub.idem.sls.source.init.process(name)
     # Get the sls file
     # render it
     # compile high data to "new" low data (bypass keyword issues)
@@ -190,24 +204,12 @@ async def apply(
     await hub.idem.state.compile(name)
     if hub.idem.RUNS[name]["errors"]:
         hub.idem.state.update_status(name, Status.COMPILATION_ERROR)
-        await hub.idem.event.put(
-            routing_key=name,
-            profile="idem-run",
-            body=hub.idem.state.sanitized_run_data(name),
-            tags={"ref": "idem.state.apply", "type": "state-run"},
-        )
         return
 
     hub.idem.state.update_status(name, Status.RUNNING)
     try:
         await hub.idem.run.init.start(name)
     finally:
-        await hub.idem.event.put(
-            routing_key=name,
-            profile="idem-run",
-            body=hub.idem.state.sanitized_run_data(name),
-            tags={"ref": "idem.state.apply", "type": "state-run"},
-        )
         hub.idem.state.update_status(name, Status.FINISHED)
 
 
@@ -221,6 +223,13 @@ async def compile_(hub, name):
             await hub.pop.loop.unwrap(ret)
 
 
+async def validate_(hub, name):
+    for mod in hub.idem.validate:
+        if hasattr(mod, "stage"):
+            ret = mod.stage(name)
+            await hub.pop.loop.unwrap(ret)
+
+
 async def single(hub, _ref_: str, _test_: bool = None, *args, **kwargs):
     """
     Run a single state and return the raw result
@@ -246,7 +255,7 @@ async def single(hub, _ref_: str, _test_: bool = None, *args, **kwargs):
     params = func.signature.parameters
 
     if "ctx" in params:
-        ctx = await hub.idem.ex.ctx(_ref_, acct_file, acct_key, acct_profile)
+        ctx = await hub.idem.acct.ctx(_ref_, acct_file, acct_key, acct_profile)
         ctx.test = _test_
         args.insert(0, ctx)
 
@@ -268,6 +277,8 @@ async def batch(
     crypto_plugin: str = "fernet",
     reconcile_plugin: str = None,
     pending_plugin: str = None,
+    esm_plugin: str = None,
+    esm_profile: str = None,
 ):
     """
     Run multiple states defined in code
@@ -297,7 +308,7 @@ async def batch(
     acct_key = acct_key or hub.OPT.acct.acct_key
     acct_profile = default_acct_profile or hub.OPT.acct.get("acct_profile", "default")
 
-    # TODO the default reconcile will change to "basic" one reconciliation loop is enabled
+    # TODO the default reconcile will change to "basic" once reconciliation loop is enabled
     reconcile_plugin = reconcile_plugin or hub.OPT.idem.get("reconciler", "none")
     pending_plugin = pending_plugin or hub.OPT.idem.get("pending", "default")
 
@@ -333,17 +344,28 @@ async def batch(
         # Default to the acct_file defined in the environment at runtime
         apply_kwargs["acct_file"] = hub.OPT.acct.acct_file
 
-    await hub.idem.state.apply(**apply_kwargs)
-
-    if hub.idem.RUNS[name]["errors"]:
-        # pop is required to remove the run from memory
-        run_data = hub.idem.RUNS.pop(name)
-        return run_data["errors"]
-
-    # Reconciliation loop
-    await hub.reconcile.init.run(
-        plugin=reconcile_plugin, pending_plugin=pending_plugin, **apply_kwargs
+    context_manager = hub.idem.managed.context(
+        run_name=name,
+        cache_dir=hub.OPT.idem.cache_dir,
+        esm_plugin=esm_plugin or hub.OPT.idem.esm_plugin,
+        esm_profile=esm_profile or hub.OPT.idem.esm_profile,
+        acct_key=acct_key,
+        acct_blob=encrypted_profiles,
+        serial_plugin=hub.OPT.idem.esm_serial_plugin,
     )
+    async with context_manager as state:
+        apply_kwargs["managed_state"] = state
+        await hub.idem.state.apply(**apply_kwargs)
+
+        if hub.idem.RUNS[name]["errors"]:
+            # pop is required to remove the run from memory
+            run_data = hub.idem.RUNS.pop(name)
+            return run_data["errors"]
+
+        # Reconciliation loop
+        await hub.reconcile.init.run(
+            plugin=reconcile_plugin, pending_plugin=pending_plugin, **apply_kwargs
+        )
 
     run_data = hub.idem.RUNS.pop(name)
     return run_data["running"]
