@@ -1,6 +1,8 @@
 import copy
 import fnmatch
 import inspect
+from typing import Any
+from typing import Dict
 
 
 def gen_tag(hub, chunk):
@@ -58,7 +60,13 @@ def find_name(hub, name, state, high):
 
 
 def format_call(
-    hub, fun, data, initial_ret=None, expected_extra_kws=(), is_class_method=None
+    hub,
+    fun,
+    data,
+    initial_ret=None,
+    expected_extra_kws=(),
+    is_class_method=None,
+    enforced_state: Dict[str, Any] = None,
 ):
     """
     Build the required arguments and keyword arguments required for the passed
@@ -77,10 +85,12 @@ def format_call(
                             methods. So, on Python 3, in case of a class method, you'd
                             need the class to which the function belongs to be instantiated
                             and this is not always wanted.
+    :param enforced_state: A dictionary with the parameters from a previous run
     :returns: A dictionary with the function required arguments and keyword
               arguments.
     """
     ret = initial_ret is not None and initial_ret or {}
+    enforced_state = enforced_state or {}
 
     ret["args"] = []
     ret["kwargs"] = {}
@@ -92,14 +102,16 @@ def format_call(
     for name, param in sig.parameters.items():
         if name == "hub":
             continue
-        if param.kind.name == "POSITIONAL_OR_KEYWORD":
+        elif param.kind.name == "POSITIONAL_OR_KEYWORD":
             if isinstance(param.default, inspect._empty):
                 args.append(name)
             else:
-                kwargs[name] = param.default
-        if param.kind.name == "KEYWORD_ONLY":
-            kwargs[name] = param.default
-        if param.kind.name == "VAR_KEYWORD":
+                # get it from enforced state before default
+                kwargs[name] = enforced_state.get(name, param.default)
+        elif param.kind.name == "KEYWORD_ONLY":
+            # get it from enforced state before default
+            kwargs[name] = enforced_state.get(name, param.default)
+        elif param.kind.name == "VAR_KEYWORD":
             keywords = True
     ret["avail_kwargs"] = copy.copy(kwargs)
     ret["avail_args"] = copy.copy(args)
