@@ -1,5 +1,7 @@
 import asyncio
 import copy
+from typing import Any
+from typing import Dict
 from typing import List
 
 import dict_tools.differ as differ
@@ -31,6 +33,7 @@ async def loop(
     acct_profile: str = None,
     acct_blob: str = None,
     subs: List[str] = None,
+    managed_state: Dict[str, Any] = None,
 ):
     """
     This loop attempts to apply states.
@@ -92,6 +95,7 @@ async def loop(
             acct_key=acct_key,
             acct_profile=acct_profile,
             acct_blob=acct_blob,
+            managed_state=managed_state,
         )
 
         current_run = hub.idem.RUNS[name]["running"]
@@ -121,7 +125,9 @@ async def loop(
 def has_passed(hub, pending_plugin, runs):
     # invoke pending plugin
     for tag in runs:
-        if hub.reconcile.pending[pending_plugin].is_pending(runs[tag]):
+        if hub.reconcile.pending[pending_plugin].is_pending(
+            ret=runs[tag], state=_tag_2_state(tag)
+        ):
             return False
     return True
 
@@ -139,7 +145,9 @@ def populate_wait_times(hub, runs):
 def get_max_wait_time(hub, pending_plugin, runs, run_count):
     max_sleep_time = DEFAULT_RECONCILE_WAIT
     for tag in runs:
-        if hub.reconcile.pending[pending_plugin].is_pending(runs[tag]):
+        if hub.reconcile.pending[pending_plugin].is_pending(
+            ret=runs[tag], state=_tag_2_state(tag)
+        ):
             state_wait = _state_to_sleep_map.get(
                 _tag_2_state(tag), DEFAULT_STATIC_RECONCILE_WAIT
             )
