@@ -1,3 +1,5 @@
+from typing import Any
+from typing import Dict
 from typing import List
 
 
@@ -16,6 +18,7 @@ async def sig_loop(
     acct_profile: str = None,
     acct_blob: str = None,
     subs: List[str] = None,
+    managed_state: Dict[str, Any] = None,
 ):
     """
     Validate the signature of the reconciliation loop function
