@@ -1,3 +1,5 @@
+from typing import Any
+from typing import Dict
 from typing import List
 
 
@@ -17,10 +19,8 @@ async def run(
     acct_profile: str = None,
     acct_blob: str = None,
     subs: List[str] = None,
+    managed_state: Dict[str, Any] = None,
 ):
-    if subs is None:
-        subs = []
-
     ret = await hub.reconcile[plugin].loop(
         pending_plugin,
         name,
@@ -35,6 +35,7 @@ async def run(
         acct_profile,
         acct_blob,
         subs,
+        managed_state,
     )
 
     return ret
