@@ -2,7 +2,7 @@ import asyncio
 from typing import Dict
 
 
-async def sleep(hub, ctx, duration: str = None) -> Dict[str, Dict]:
+async def sleep(hub, ctx, name, duration: str = None) -> Dict[str, Dict]:
     """
     Sleep resource to be used by other resources to delay creation/deletion for a duration of time in seconds
 
@@ -21,7 +21,11 @@ async def sleep(hub, ctx, duration: str = None) -> Dict[str, Dict]:
 
     """
     result = dict(
-        comment="", old_state={}, new_state={}, name=f"Sleep-{duration}sec", result=True
+        comment=f"Sleep-{duration}sec",
+        old_state={},
+        new_state={},
+        name=name,
+        result=True,
     )
 
     if duration is None or str(duration) == 0:
